============================
Salt 2014.1.13 Release Notes
============================

:release: 2014-10-14

Version 2014.1.13 is another bugfix release for :doc:`2014.1.0
</topics/releases/2014.1.0>`.  Changes include:

- Fix ``sftp_file`` by checking the exit status code of scp (which broke salt-cloud) (:issue:`16599`)
